@@ -26,6 +26,9 @@ from sets import Set
 
 BUTTON_LABEL_MAX_LENGTH = 30
 
+FLAG_PATH = "/usr/share/iso-flag-png/%s.png"
+FLAG_SIZE = 16
+
 def remove_repository_via_cli(line, codename, forceYes):
     if line.startswith("ppa:"):
         user, sep, ppa_name = line.split(":")[1].partition("/")
@@ -435,17 +438,21 @@ class MirrorSelectionDialog(object):
     def _update_list(self):
         self._mirrors_model.clear()
         for mirror in self.visible_mirrors:
-            flag = "/usr/lib/linuxmint/mintSources/flags/generic.png"
-            if os.path.exists("/usr/lib/linuxmint/mintSources/flags/%s.png" % mirror.country_code.lower()):
-                flag = "/usr/lib/linuxmint/mintSources/flags/%s.png" % mirror.country_code.lower()
-            country_name = self.country_info.get_country_name(mirror.country_code)
+            if mirror.country_code == "WD":
+                flag = FLAG_PATH % '_united_nations'
+                country_name = _("Worldwide")
+            else:
+                flag = FLAG_PATH % mirror.country_code.lower()
+                country_name = self.country_info.get_country_name(mirror.country_code)
+            if not os.path.exists(flag):
+                flag = FLAG_PATH % '_generic'
             tooltip = country_name
             if mirror.name != mirror.url:
                 tooltip = "%s: %s" % (country_name, mirror.name)
             self._mirrors_model.append((
                 mirror,
                 mirror.url,
-                gtk.gdk.pixbuf_new_from_file(flag),
+                gtk.gdk.pixbuf_new_from_file_at_size(flag, -1, FLAG_SIZE),
                 0,
                 None,
                 tooltip,
@@ -597,6 +604,7 @@ class MirrorSelectionDialog(object):
                 if country["cca3"] in self.local_country["borders"]:
                     self.bordering_countries.append(country_code)
 
+        self.worldwide_mirrors = []
         self.local_mirrors = []
         self.bordering_mirrors = []
         self.subregional_mirrors = []
@@ -605,7 +613,10 @@ class MirrorSelectionDialog(object):
         self.other_mirrors = []
 
         for mirror in mirrors:
-            if mirror.country_code == self.local_country_code:
+            if mirror.country_code == "WD":
+                self.worldwide_mirrors.append(mirror)
+                print (mirror)
+            elif mirror.country_code == self.local_country_code:
                 self.local_mirrors.append(mirror)
             elif mirror.country_code in self.bordering_countries:
                 self.bordering_mirrors.append(mirror)
@@ -618,11 +629,12 @@ class MirrorSelectionDialog(object):
             else:
                 self.other_mirrors.append(mirror)
 
+        self.worldwide_mirrors = sorted(self.worldwide_mirrors, key=lambda x: x.country_code)
         self.bordering_mirrors = sorted(self.bordering_mirrors, key=lambda x: x.country_code)
         self.subregional_mirrors = sorted(self.subregional_mirrors, key=lambda x: x.country_code)
         self.regional_mirrors = sorted(self.regional_mirrors, key=lambda x: x.country_code)
 
-        self.visible_mirrors = self.local_mirrors + self.bordering_mirrors + self.subregional_mirrors + self.regional_mirrors + self.official_mirrors
+        self.visible_mirrors = self.worldwide_mirrors + self.local_mirrors + self.bordering_mirrors + self.subregional_mirrors + self.regional_mirrors + self.official_mirrors
 
         if self.local_country_code in ["IL"]:
             # For some countries, geographical proximity doesn't equate to faster mirrors.
@@ -674,7 +686,7 @@ class Application(object):
 
         self._main_window.set_title(_("Software Sources"))
 
-        self._main_window.set_icon_from_file("/usr/share/icons/hicolor/scalable/apps/software-sources.svg")
+        self._main_window.set_icon_name("mintsources")
 
         self._notebook = self.builder.get_object("notebook")
         self._official_repositories_box = self.builder.get_object("official_repositories_box")
@@ -1467,8 +1479,8 @@ class Application(object):
         self.update_flags()
 
     def update_flags(self):
-        self.builder.get_object("image_mirror").set_from_file("/usr/lib/linuxmint/mintSources/flags/generic.png")
-        self.builder.get_object("image_base_mirror").set_from_file("/usr/lib/linuxmint/mintSources/flags/generic.png")
+        mint_flag_path = FLAG_PATH % '_generic'
+        base_flag_path = FLAG_PATH % '_generic'
 
         selected_mirror = self.selected_mirror
         if selected_mirror[-1] == "/":
@@ -1484,8 +1496,13 @@ class Application(object):
             else:
                 url = mirror.url
             if url in selected_mirror:
-                if os.path.exists("/usr/lib/linuxmint/mintSources/flags/%s.png" % mirror.country_code.lower()):
-                    self.builder.get_object("image_mirror").set_from_file("/usr/lib/linuxmint/mintSources/flags/%s.png" % mirror.country_code.lower())
+                if mirror.country_code == "WD":
+                    flag = FLAG_PATH % '_united_nations'
+                else:
+                    flag = FLAG_PATH % mirror.country_code.lower()
+                if os.path.exists(flag):
+                    mint_flag_path = flag
+                    break
 
         for mirror in self.base_mirrors:
             if mirror.url[-1] == "/":
@@ -1493,8 +1510,15 @@ class Application(object):
             else:
                 url = mirror.url
             if url in selected_base_mirror:
-                if os.path.exists("/usr/lib/linuxmint/mintSources/flags/%s.png" % mirror.country_code.lower()):
-                    self.builder.get_object("image_base_mirror").set_from_file("/usr/lib/linuxmint/mintSources/flags/%s.png" % mirror.country_code.lower())
+                if os.path.exists(FLAG_PATH % mirror.country_code.lower()):
+                    base_flag_path = FLAG_PATH % mirror.country_code.lower()
+                    break
+
+        pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(mint_flag_path, -1, FLAG_SIZE)
+        self.builder.get_object("image_mirror").set_from_pixbuf(pixbuf)
+
+        pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(base_flag_path, -1, FLAG_SIZE)
+        self.builder.get_object("image_base_mirror").set_from_pixbuf(pixbuf)
 
     def get_clipboard_text(self, source_type):
         clipboard = gtk.Clipboard(display=gtk.gdk.display_get_default(), selection="CLIPBOARD")
